==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-workflow/src/main/java/de/fzj/unicore/ucc/workflow/GlobalFileImporter.java <==
package de.fzj.unicore.ucc.workflow;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.List;

import org.chemomentum.common.ws.ILocationManager;
import org.chemomentum.dataManagement.locationManager.StoreLocationRequestDocument;
import org.chemomentum.dataManagement.locationManager.StoreLocationRequestDocument.StoreLocationRequest.Input;
import org.unigrids.services.atomic.types.ProtocolType;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

import de.fzj.unicore.uas.client.StorageClient;
import de.fzj.unicore.ucc.MessageWriter;
import de.fzj.unicore.wsrflite.xmlbeans.client.IRegistryQuery;
import eu.unicore.security.util.client.IClientProperties;
import eu.unicore.security.xfireutil.client.SecuredXFireClientFactory;

/**
 * uploads a local file to the global storage,
 * and registers it with the location mapper.
 * 
 * @author schuller
 */
public class GlobalFileImporter {

	private IRegistryQuery registry;

	private String workflowID;

	private MessageWriter msg;

	private boolean haveInit;

	private ILocationManager locationMapper;
	private IClientProperties securityProperties;
	private StorageClient storageClient;

	//EPR of location manager service
	private EndpointReferenceType epr;

	public GlobalFileImporter(){
	}

	public GlobalFileImporter(IRegistryQuery registry, IClientProperties sec, String workflowID, MessageWriter msg){
		this.registry=registry;
		this.securityProperties=sec;
		this.workflowID=workflowID;
		this.msg=msg;
	}

	public IRegistryQuery getRegistry() {
		return registry;
	}

	public void setRegistry(IRegistryQuery registry) {
		this.registry = registry;
	}

	public String getWorkflowID() {
		return workflowID;
	}

	public void setWorkflowID(String workflowID) {
		this.workflowID = workflowID;
	}

	/**
	 * imports a local file and registers it with the location Mapper
	 *  
	 * @param localPath - the local file to import
	 * @param globalName - the name to register with the locationmapper. This name does not yet
	 *                     include the workflow id
	 * @throws IOException
	 */
	public void importFile(String localPath, String globalName)throws IOException{
		try{
			initialise();
		}
		catch(Exception e){
			msg.error("Can't initialise", e);
			throw new IOException("Can't initialise! Reason: "+e.getMessage());
		}
		String physicalLocation=null;
		String name="inputfiles/"+new File(localPath).getName();
		try{
			//Protocol: Should always have BFT
			physicalLocation="BFT:"+storageClient.getEPR().getAddress().getStringValue()+"#/"+workflowID+"/"+name;
			registerName(globalName, physicalLocation);
		}
		catch(Exception e){
			msg.error("Can't register global name", e);
			throw new IOException("Can't register global name! Reason: "+e.getMessage());
		}
		try{
			FileInputStream source=new FileInputStream(new File(localPath).getAbsolutePath());
			storageClient.getImport("/"+workflowID+"/"+name, ProtocolType.BFT, ProtocolType.RBYTEIO).writeAllData(source);
		}
		catch(Exception e){
			msg.error("Can't register global name", e);
			throw new IOException("Can't register global name! Reason: "+e.getMessage());
		}

	}

	protected void registerName(String name, String location)throws Exception{
		StoreLocationRequestDocument requestDocument=StoreLocationRequestDocument.Factory.newInstance();
		Input in= requestDocument.addNewStoreLocationRequest().addNewInput();
		in.setLogicalName(name);
		in.addNewPhysicalLocation().setStringValue(location);
		locationMapper.storeLocation(requestDocument);
		msg.verbose("Registered global name <"+name+"> with location <"+location+">");
	}

	//calls location mapper registed in registry
	protected void initialise(){
		if(haveInit)return;
		haveInit=true;
		try{
			List<EndpointReferenceType> available=registry.listServices(ILocationManager.PORT);
			int index=0;
			if(available.size()==0){
				msg.message("No location mapping service available!");
				index=-1;
			}
			else if(available.size()>1){
				//TODO
				msg.verbose("Too many location mapper services available... using first one");
				index=0;
			}
			if(index>=0){
				epr=available.get(0);
				String url=epr.getAddress().getStringValue();
				msg.verbose("Querying location mapping service at "+url);
				locationMapper=new SecuredXFireClientFactory(securityProperties).createPlainWSProxy(ILocationManager.class,url);
				return;
			}
		}catch(Exception e){
			msg.error("Can't access location mapper.", e);
		}
	}

	public void setStorage(StorageClient sms){
		this.storageClient=sms;
	}

	public void setMsg(MessageWriter msg) {
		this.msg = msg;
	}

}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-workflow/src/main/java/de/fzj/unicore/ucc/workflow/GlobalFileImporter.java <==
package de.fzj.unicore.ucc.workflow;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.util.List;

import org.chemomentum.common.ws.ILocationManager;
import org.chemomentum.dataManagement.locationManager.StoreLocationRequestDocument;
import org.chemomentum.dataManagement.locationManager.StoreLocationRequestDocument.StoreLocationRequest.Input;
import org.unigrids.services.atomic.types.ProtocolType;
import org.w3.x2005.x08.addressing.EndpointReferenceType;

import de.fzj.unicore.uas.client.StorageClient;
import de.fzj.unicore.ucc.MessageWriter;
import de.fzj.unicore.wsrflite.xmlbeans.client.IRegistryQuery;
import eu.unicore.security.xfireutil.client.UnicoreXFireClientFactory;
import eu.unicore.util.httpclient.IClientConfiguration;

/**
 * uploads a local file to the global storage,
 * and registers it with the location mapper.
 * 
 * @author schuller
 */
public class GlobalFileImporter {

	private IRegistryQuery registry;

	private String workflowID;

	private MessageWriter msg;

	private boolean haveInit;

	private ILocationManager locationMapper;
	private IClientConfiguration securityProperties;
	private StorageClient storageClient;

	//EPR of location manager service
	private EndpointReferenceType epr;

	public GlobalFileImporter(){
	}

	public GlobalFileImporter(IRegistryQuery registry, IClientConfiguration sec, String workflowID, MessageWriter msg){
		this.registry=registry;
		this.securityProperties=sec;
		this.workflowID=workflowID;
		this.msg=msg;
	}

	public IRegistryQuery getRegistry() {
		return registry;
	}

	public void setRegistry(IRegistryQuery registry) {
		this.registry = registry;
	}

	public String getWorkflowID() {
		return workflowID;
	}

	public void setWorkflowID(String workflowID) {
		this.workflowID = workflowID;
	}

	/**
	 * imports a local file and registers it with the location Mapper
	 *  
	 * @param localPath - the local file to import
	 * @param globalName - the name to register with the locationmapper. This name does not yet
	 *                     include the workflow id
	 * @throws IOException
	 */
	public void importFile(String localPath, String globalName)throws IOException{
		try{
			initialise();
		}
		catch(Exception e){
			msg.error("Can't initialise", e);
			throw new IOException("Can't initialise! Reason: "+e.getMessage());
		}
		String physicalLocation=null;
		String name="inputfiles/"+new File(localPath).getName();
		try{
			//Protocol: Should always have BFT
			physicalLocation="BFT:"+storageClient.getEPR().getAddress().getStringValue()+"#/"+workflowID+"/"+name;
			registerName(globalName, physicalLocation);
		}
		catch(Exception e){
			msg.error("Can't register global name", e);
			throw new IOException("Can't register global name! Reason: "+e.getMessage());
		}
		try{
			FileInputStream source=new FileInputStream(new File(localPath).getAbsolutePath());
			storageClient.getImport("/"+workflowID+"/"+name, ProtocolType.BFT, ProtocolType.RBYTEIO).writeAllData(source);
		}
		catch(Exception e){
			msg.error("Can't register global name", e);
			throw new IOException("Can't register global name! Reason: "+e.getMessage());
		}

	}

	protected void registerName(String name, String location)throws Exception{
		StoreLocationRequestDocument requestDocument=StoreLocationRequestDocument.Factory.newInstance();
		Input in= requestDocument.addNewStoreLocationRequest().addNewInput();
		in.setLogicalName(name);
		in.addNewPhysicalLocation().setStringValue(location);
		locationMapper.storeLocation(requestDocument);
		msg.verbose("Registered global name <"+name+"> with location <"+location+">");
	}

	//calls location mapper registed in registry
	protected void initialise(){
		if(haveInit)return;
		haveInit=true;
		try{
			List<EndpointReferenceType> available=registry.listServices(ILocationManager.PORT);
			int index=0;
			if(available.size()==0){
				msg.message("No location mapping service available!");
				index=-1;
			}
			else if(available.size()>1){
				//TODO
				msg.verbose("Too many location mapper services available... using first one");
				index=0;
			}
			if(index>=0){
				epr=available.get(0);
				String url=epr.getAddress().getStringValue();
				msg.verbose("Querying location mapping service at "+url);
				locationMapper=new UnicoreXFireClientFactory(securityProperties).createPlainWSProxy(ILocationManager.class,url);
				return;
			}
		}catch(Exception e){
			msg.error("Can't access location mapper.", e);
		}
	}

	public void setStorage(StorageClient sms){
		this.storageClient=sms;
	}

	public void setMsg(MessageWriter msg) {
		this.msg = msg;
	}

}
